==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/registry/RegistryEntry.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * @copyright 2015 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Development**
 * @module bajaux/registry/RegistryEntry
 */
define(['underscore', 'nmodule/js/rc/asyncUtils/asyncUtils'], function (_, asyncUtils) {
  'use strict';

  var doRequire = asyncUtils.doRequire;

  ////////////////////////////////////////////////////////////////
  // Support functions
  ////////////////////////////////////////////////////////////////

  /**
   * Check to see if any of the desired values exist in the array.
   *
   * @inner
   * @param {Array} toTest
   * @param {Array} desired
   * @returns {boolean} true if `desired` is empty ("I don't care") or if any
   * of the values in `desired` also exist in `toTest`
   */
  function hasAny(toTest, desired) {
    if (!desired.length) {
      return true; //don't care
    }
    for (var i = 0; i < desired.length; i++) {
      if (toTest.indexOf(desired[i]) >= 0) {
        return true;
      }
    }
  }

  /**
   * Check to see if all of the desired values exist in the array.
   *
   * @inner
   * @param {Array} toTest
   * @param {Array} desired
   * @returns {boolean} true if all values in `desired` also exist in `toTest`
   * (independent of order)
   */
  function hasAll(toTest, desired) {
    return !_.difference(desired, toTest).length;
  }

  ////////////////////////////////////////////////////////////////
  // Exports
  ////////////////////////////////////////////////////////////////

  /**
   * An entry intended to be stored in a local `Registry`, representing a single
   * RequireJS module. Additional parameters can be used to store metadata
   * about this module, allowing it to be queried later in more detail.
   *
   * There is usually no reason to instantiate this class directly;
   * a `Registry` will create them as needed.
   *
   * @class
   * @alias module:bajaux/registry/RegistryEntry
   * @param {module:bajaux/registry/Registry~QueryParams} params
   * @since Niagara 4.10
   */
  var RegistryEntry = /*#__PURE__*/function () {
    function RegistryEntry(params) {
      _classCallCheck(this, RegistryEntry);
      if (!params || typeof params.rjs !== 'string') {
        throw new Error('rjs parameter required');
      }
      this.$rjs = params.rjs;
      this.$deps = params.deps || [];
      this.$tags = params.tags || [];
    }

    /**
     * Resolve the RequireJS module (and any dependencies) that is represented
     * by this module.
     *
     * @returns {Promise} promise to be resolved with the contents of
     * the RequireJS module, or rejected if the module ID or any of its
     * dependencies could not be loaded
     */
    return _createClass(RegistryEntry, [{
      key: "resolve",
      value: function resolve() {
        return doRequire(this.$rjs, this.$deps);
      }

      /**
       * Check to see if this entry's metadata matches a registry query.
       *
       * @param {module:bajaux/registry/Registry~QueryParams|module:bajaux/registry/RegistryEntry} [params]
       * @returns {boolean} true if this entry matches the query parameters and
       * so should be included in the results
       */
    }, {
      key: "matches",
      value: function matches(params) {
        if (params instanceof RegistryEntry) {
          //noinspection JSUnresolvedFunction
          params = params.toJSON();
        }
        params = params || {};
        var any = params.hasAny || params.tags,
          all = params.hasAll,
          rjs = params.rjs,
          deps = params.deps;
        if (any && !hasAny(this.$tags, any)) {
          return false;
        }
        if (all && !hasAll(this.$tags, all)) {
          return false;
        }
        if (rjs && this.$rjs !== rjs) {
          return false;
        }

        //noinspection RedundantIfStatementJS
        if (deps && !hasAll(this.$deps, deps)) {
          return false;
        }
        return true;
      }

      /**
       * Get the RequireJS ID for this entry.
       * @returns {string}
       */
    }, {
      key: "getJsId",
      value: function getJsId() {
        return this.$rjs;
      }

      /**
       * Get the list of RequireJS dependencies (typically builtfiles) that must
       * be loaded before requiring the main RequireJS ID.
       * @returns {Array.<String>}
       */
    }, {
      key: "getJsDependencies",
      value: function getJsDependencies() {
        return this.$deps;
      }

      /**
       * Get a list of tags that serve as metadata for this entry.
       * @returns {Array.<String>}
       */
    }, {
      key: "getTags",
      value: function getTags() {
        return this.$tags;
      }

      /**
       * Return a raw object representation of this entry. As a contractual
       * requirement, the output of this function should be able to be passed right
       * back to the constructor to create a new instance. Return `undefined` to
       * indicate that this entry should never be serialized.
       * @returns {Object|undefined}
       */
    }, {
      key: "toJSON",
      value: function toJSON() {
        return {
          rjs: this.getJsId(),
          deps: this.getJsDependencies(),
          tags: this.getTags()
        };
      }
    }]);
  }();
  /**
   * Compute a hash string for a query params object. Since the registry
   * contents should never change while apps are running, we can memoize calls
   * to registry query functions.
   *
   * @private
   * @param {Object} params params object as expected by `matches()`
   * @returns {String} a hash string
   */
  RegistryEntry.$hashParams = function (params) {
    params = params || {};
    var tags = params.tags,
      all = params.hasAll,
      any = params.hasAny,
      rjs = params.rjs,
      deps = params.deps;
    return 't' + (tags ? tags.join() : '') + 'r' + (rjs || '') + 'd' + (deps ? deps.join() : '') + 'l' + (all ? all.join() : '') + 'y' + (any ? any.join() : '');
  };
  return RegistryEntry;
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/registry/RegistryEntry.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/**
 * @copyright 2015 Tridium, Inc. All Rights Reserved.
 * @author Logan Byam
 */

/**
 * API Status: **Development**
 * @module bajaux/registry/RegistryEntry
 */
define(['log!bajaux.registry.RegistryEntry', 'Promise', 'underscore', 'nmodule/js/rc/asyncUtils/asyncUtils'], function (log, Promise, _, asyncUtils) {
  'use strict';

  var logSevere = log.severe.bind(log);
  var difference = _.difference,
    flatten = _.flatten;
  var doRequire = asyncUtils.doRequire;

  ////////////////////////////////////////////////////////////////
  // Support functions
  ////////////////////////////////////////////////////////////////

  /**
   * Check to see if any of the desired values exist in the array.
   *
   * @inner
   * @param {Array} toTest
   * @param {Array} desired
   * @returns {boolean} true if `desired` is empty ("I don't care") or if any
   * of the values in `desired` also exist in `toTest`
   */
  function hasAny(toTest, desired) {
    if (!desired.length) {
      return true; //don't care
    }
    for (var i = 0; i < desired.length; i++) {
      if (toTest.indexOf(desired[i]) >= 0) {
        return true;
      }
    }
  }

  /**
   * Check to see if all of the desired values exist in the array.
   *
   * @inner
   * @param {Array} toTest
   * @param {Array} desired
   * @returns {boolean} true if all values in `desired` also exist in `toTest`
   * (independent of order)
   */
  function hasAll(toTest, desired) {
    return !difference(desired, toTest).length;
  }

  ////////////////////////////////////////////////////////////////
  // Exports
  ////////////////////////////////////////////////////////////////

  /**
   * An entry intended to be stored in a local `Registry`, representing a single
   * RequireJS module. Additional parameters can be used to store metadata
   * about this module, allowing it to be queried later in more detail.
   *
   * There is usually no reason to instantiate this class directly;
   * a `Registry` will create them as needed.
   *
   * @class
   * @alias module:bajaux/registry/RegistryEntry
   * @param {module:bajaux/registry/Registry~QueryParams} params
   * @since Niagara 4.10
   */
  var RegistryEntry = /*#__PURE__*/function () {
    function RegistryEntry(params) {
      _classCallCheck(this, RegistryEntry);
      if (!params || typeof params.rjs !== 'string') {
        throw new Error('rjs parameter required');
      }
      this.$rjs = params.rjs;
      this.$deps = params.deps || [];
      this.$tags = params.tags || [];
    }

    /**
     * Resolve the RequireJS module (and any dependencies) that is represented
     * by this module.
     *
     * @returns {Promise} promise to be resolved with the contents of
     * the RequireJS module, or rejected if the module ID or any of its
     * dependencies could not be loaded
     */
    return _createClass(RegistryEntry, [{
      key: "resolve",
      value: function resolve() {
        return doRequire(this.$rjs, this.$deps)["catch"](function (e) {
          logSevere(e);
          throw e;
        });
      }

      /**
       * Check to see if this entry's metadata matches a registry query.
       *
       * @param {module:bajaux/registry/Registry~QueryParams|module:bajaux/registry/RegistryEntry} [params]
       * @returns {boolean} true if this entry matches the query parameters and
       * so should be included in the results
       */
    }, {
      key: "matches",
      value: function matches(params) {
        if (params instanceof RegistryEntry) {
          //noinspection JSUnresolvedFunction
          params = params.toJSON();
        }
        params = params || {};
        var any = params.hasAny || params.tags,
          all = params.hasAll,
          rjs = params.rjs,
          deps = params.deps;
        if (any && !hasAny(this.$tags, any)) {
          return false;
        }
        if (all && !hasAll(this.$tags, all)) {
          return false;
        }
        if (rjs && this.$rjs !== rjs) {
          return false;
        }

        //noinspection RedundantIfStatementJS
        if (deps && !hasAll(flatten(this.$deps), flatten(deps))) {
          return false;
        }
        return true;
      }

      /**
       * Get the RequireJS ID for this entry.
       * @returns {string}
       */
    }, {
      key: "getJsId",
      value: function getJsId() {
        return this.$rjs;
      }

      /**
       * Get the list of RequireJS dependencies (typically builtfiles) that must
       * be loaded before requiring the main RequireJS ID.
       * @returns {Array.<Array.<String>>}
       */
    }, {
      key: "getJsDependencies",
      value: function getJsDependencies() {
        return this.$deps;
      }

      /**
       * Get a list of tags that serve as metadata for this entry.
       * @returns {Array.<String>}
       */
    }, {
      key: "getTags",
      value: function getTags() {
        return this.$tags;
      }

      /**
       * Return a raw object representation of this entry. As a contractual
       * requirement, the output of this function should be able to be passed right
       * back to the constructor to create a new instance. Return `undefined` to
       * indicate that this entry should never be serialized.
       * @returns {Object|undefined}
       */
    }, {
      key: "toJSON",
      value: function toJSON() {
        return {
          rjs: this.getJsId(),
          deps: this.getJsDependencies(),
          tags: this.getTags()
        };
      }
    }]);
  }();
  /**
   * Compute a hash string for a query params object. Since the registry
   * contents should never change while apps are running, we can memoize calls
   * to registry query functions.
   *
   * @private
   * @param {Object} params params object as expected by `matches()`
   * @returns {String} a hash string
   */
  RegistryEntry.$hashParams = function (params) {
    params = params || {};
    var tags = params.tags,
      all = params.hasAll,
      any = params.hasAny,
      rjs = params.rjs,
      deps = params.deps;
    return 't' + (tags ? tags.join() : '') + 'r' + (rjs || '') + 'd' + (deps ? deps.join() : '') + 'l' + (all ? all.join() : '') + 'y' + (any ? any.join() : '');
  };
  return RegistryEntry;
});
